@@ -5,15 +5,15 @@ hook_plot_html = function(x, options) {
   fig.num = options$fig.num = options$fig.num %n% 1L
   fig.cur = options$fig.cur %n% 1L
 
-  if(options$fig.show == 'animate') {
+  if (options$fig.show == 'animate') {
     # Don't print out intermediate plots if we're animating
-    return(if(fig.cur < fig.num) '' else opts_knit$get('animation.fun')(x, options))
+    return(if (fig.cur < fig.num) '' else opts_knit$get('animation.fun')(x, options))
   }
   ai = options$fig.show == 'asis'
   plot1 = ai || fig.cur <= 1L; plot2 = ai || fig.cur == fig.num
-  d1 = if (plot1) str_c(if (out_format('html')) '</div>',
+  d1 = if (plot1) paste0(if (out_format('html')) '</div>',
                         sprintf('<div class="rimage %s">', options$fig.align))
-  d2 = if (plot2) str_c('</div>', if (out_format('html')) '<div class="rcode">')
+  d2 = if (plot2) paste0('</div>', if (out_format('html')) '<div class="rcode">')
   paste(
     d1, .img.tag(
       .upload.url(x), options$out.width, options$out.height, .img.cap(options),
@@ -73,10 +73,10 @@ hook_ffmpeg = function(x, options, format = '.webm') {
   x = c(sans_ext(x), file_ext(x))
   fig.num = options$fig.num
   # set up the ffmpeg run
-  fig.fname = str_c(sub(str_c(fig.num, '$'), '%d', x[1]), '.', x[2])
-  mov.fname = str_c(sub(paste(fig.num, '$',sep = ''), '', x[1]), format)
+  fig.fname = paste0(sub(paste0(fig.num, '$'), '%d', x[1]), '.', x[2])
+  mov.fname = paste0(sub(paste(fig.num, '$', sep = ''), '', x[1]), format)
 
-  ffmpeg.cmd = paste('ffmpeg', '-y', '-r', 1/options$interval,
+  ffmpeg.cmd = paste('ffmpeg', '-y', '-r', 1 / options$interval,
                      '-i', fig.fname, mov.fname)
   message('executing: ', ffmpeg.cmd)
   system(ffmpeg.cmd, ignore.stdout = TRUE)
@@ -88,7 +88,7 @@ hook_ffmpeg = function(x, options, format = '.webm') {
     sprintf('height="%s"', options$out.height), opts
   )
   sprintf('<video %s><source src="%s" />video of chunk %s</video>',
-          opts, str_c(opts_knit$get('base.url'), mov.fname), options$label)
+          opts, paste0(opts_knit$get('base.url'), mov.fname), options$label)
 }
 
 # use SciAnimator to create animations
@@ -110,7 +110,7 @@ hook_scianimator = function(x, options) {
   (function($) {
     $(document).ready(function() {
       var imgs = Array(%s);
-      for (i=0; ; i++) {
+      for (i = 0; ; i++) {
         if (i == imgs.length) break;
         imgs[i] = "%s%s" + (i + 1) + ".%s";
       }
@@ -124,7 +124,7 @@ hook_scianimator = function(x, options) {
   })(jQuery);
 </script>
 ',
-          id, fig.num, base, sub(str_c(fig.num, '$'), '', x[1]), x[2], id,
+          id, fig.num, base, sub(paste0(fig.num, '$'), '', x[1]), x[2], id,
           options$interval * 1000, id)
 }
 
@@ -136,7 +136,7 @@ hook_r2swf = function(x, options) {
   x = c(sans_ext(x), file_ext(x))
   fig.num = options$fig.num
   # set up the R2SWF run
-  fig.name = str_c(sub(str_c(fig.num, '$'), '', x[1]), 1:fig.num, '.', x[2])
+  fig.name = paste0(sub(paste0(fig.num, '$'), '', x[1]), 1:fig.num, '.', x[2])
   swf.name = fig_path('.swf', options, NULL)
 
   w = options$out.width %n% (options$fig.width * options$dpi)
@@ -146,7 +146,7 @@ hook_r2swf = function(x, options) {
   file2swf = getFromNamespace('file2swf', 'R2SWF')
   swfhtml = swf2html(file2swf(files = fig.name, swf.name, interval = options$interval),
                      output = FALSE, fragment = TRUE,  width = w, height = h)
-  if(options$fig.align == 'default') return(swfhtml)
+  if (options$fig.align == 'default') return(swfhtml)
   sprintf(paste('<div align = "%s">\n', swfhtml, '\n</div>'), options$fig.align)
 }
 
@@ -158,7 +158,7 @@ render_html = function() {
   # use div with different classes
   html.hook = function(name) {
     force(name)
-    function (x, options) {
+    function(x, options) {
       x = if (name == 'source') {
         c(hilight_source(x, 'html', options), '')
       } else escape_html(x)
