@@ -9,7 +9,7 @@
 #' input document; in other words, a single call like
 #' \code{knit('my_input.Rnw')} is usually enough. This function will try to
 #' determine many internal settings automatically. For the sake of
-#' reproducibility, it is a better practice to include the options inside the
+#' reproducibility, it is better practice to include the options inside the
 #' input document (to be self-contained), instead of setting them before
 #' knitting the document.
 #'
@@ -32,8 +32,8 @@
 #' \code{apat$rnw}, \samp{tex} uses the list \code{apat$tex}, \samp{brew} uses
 #' \code{apat$brew} and HTML files use \code{apat$html}; for unkown extensions,
 #' the content of the input document is matched against all pattern lists to
-#' automatically which pattern list is being used. You can also manually set the
-#' pattern list using the \code{\link{knit_patterns}} object or the
+#' automatically determine which pattern list is being used. You can also manually
+#' set the pattern list using the \code{\link{knit_patterns}} object or the
 #' \code{\link{pat_rnw}} series functions in advance and \pkg{knitr} will
 #' respect the setting.
 #'
@@ -43,6 +43,13 @@
 #' etc. The output hooks decide how to mark up the results (you can customize
 #' the hooks).
 #'
+#' The name \code{knit} comes from its counterpart \samp{weave} (as in Sweave),
+#' and the name \code{purl} (as \samp{tangle} in Stangle) comes from a knitting
+#' method `knit one, purl one'.
+#'
+#' If the input document has child documents, they will also be compiled
+#' recursively. See \code{\link{knit_child}}.
+#'
 #' See the package website and manuals in the references to know more about
 #' \pkg{knitr}, including the full documentation of chunk options and demos,
 #' etc.
@@ -64,20 +71,19 @@
 #'   \code{NULL}, the compiled output is returned as a character vector. In
 #'   other words, if you provide a file input, you get an output filename; if
 #'   you provide a character vector input, you get a character vector output.
-#' @note The name \code{knit} comes from its counterpart \samp{weave} (as in
-#'   Sweave), and the name \code{purl} (as \samp{tangle} in Stangle) comes from
-#'   a knitting method `knit one, purl one'.
-#'
-#'   If the input document has child documents, they will also be compiled
-#'   recursively. See \code{\link{knit_child}}.
-#'
-#'   The working directory when evaluating R code chunks is the directory of the
-#'   input document by default, so if the R code involves external files (like
-#'   \code{read.table()}), it is better to put these files under the same
+#' @note The working directory when evaluating R code chunks is the directory of
+#'   the input document by default, so if the R code involves external files
+#'   (like \code{read.table()}), it is better to put these files under the same
 #'   directory of the input document so that we can use relative paths. However,
 #'   it is possible to change this directory with the package option
 #'   \code{\link{opts_knit}$set(root.dir = ...)} so all paths in code chunks are
-#'   relative to this \code{root.dir}.
+#'   relative to this \code{root.dir}. It is not recommended to change the
+#'   working directory via \code{\link{setwd}()} in a code chunk, because it may
+#'   lead to terrible consequences (e.g. figure and cache files may be written to
+#'   wrong places). If you do use \code{setwd()}, please note that \pkg{knitr}
+#'   will always restore the working directory to the original one. Whenever you
+#'   feel confused, print \code{getwd()} in a code chunk to see what the working
+#'   directory really is.
 #'
 #'   The arguments \code{input} and \code{output} do not have to be restricted
 #'   to files; they can be \code{stdin()}/\code{stdout()} or other types of
@@ -90,10 +96,10 @@
 #'   be in the current working directory (e.g. \file{foo.tex} instead of
 #'   \file{somewhere/foo.tex}), especially when the output has external
 #'   dependencies such as figure files. If you want to write the output to a
-#'   different directory, you are recommended to set the working directory to
+#'   different directory, it is recommended to set the working directory to
 #'   that directory before you knit a document. For example, if the source
-#'   document is \file{foo.Rmd}, and the expected output is \file{out/foo.md},
-#'   you can do \code{setwd('out/'); knit('../foo.Rmd')}, instead of
+#'   document is \file{foo.Rmd} and the expected output is \file{out/foo.md},
+#'   you can write \code{setwd('out/'); knit('../foo.Rmd')} instead of
 #'   \code{knit('foo.Rmd', 'out/foo.md')}.
 #'
 #'   N.B. There is no guarantee that the R script generated by \code{purl()} can
@@ -106,8 +112,8 @@
 #'   people \href{http://bit.ly/SnLi6h}{just do not get it}.
 #' @export
 #' @references Package homepage: \url{http://yihui.name/knitr/}. The \pkg{knitr}
-#'   \href{http://bit.ly/knitr-main}{main manual}: and
-#'   \href{http://bit.ly/knitr-graphics}{graphics manual}.
+#'   \href{http://yihui.name/knitr/demo/manual/}{main manual}: and
+#'   \href{http://yihui.name/knitr/demo/graphics}{graphics manual}.
 #'
 #'   See \code{citation('knitr')} for the citation information.
 #' @examples library(knitr)
@@ -172,7 +178,8 @@ knit = function(input, output = NULL, tangle = FALSE, text = NULL, quiet = FALSE
     # have been generated by hook_purl)
     if (is.character(output) && !child_mode()) {
       out.purl = sub_ext(input, 'R')
-      if (tangle && file_test('-nt', out.purl, input)) return(out.purl)
+      if (same_file(output, out.purl) && tangle && file_test('-nt', out.purl, input))
+        return(out.purl)
       otangle = .knitEnv$tangle.file  # the tangled R script
       .knitEnv$tangle.file = normalizePath(out.purl, mustWork = FALSE)
       .knitEnv$tangle.start = FALSE
@@ -199,7 +206,7 @@ knit = function(input, output = NULL, tangle = FALSE, text = NULL, quiet = FALSE
 
   apat = all_patterns; opat = knit_patterns$get()
   on.exit(knit_patterns$restore(opat), add = TRUE)
-  if (length(opat) == 0 || all(sapply(opat, is.null))) {
+  if (length(opat) == 0 || all(vapply(opat, is.null, logical(1)))) {
     # use ext if cannot auto detect pattern
     if (is.null(pattern <- detect_pattern(text, ext))) {
       # nothing to be executed; just return original input
@@ -221,10 +228,21 @@ knit = function(input, output = NULL, tangle = FALSE, text = NULL, quiet = FALSE
   }
 
   if (is.null(out_format())) auto_format(ext)
-  # in child mode, strip off the YAML metadata in Markdown if exists
-  if (child_mode() && out_format('markdown') && grepl('^---\\s*$', text[1])) {
-    i = grep('^---\\s*$', text)
-    if (length(i) >= 2) text = text[-(1:i[2])]
+
+  params = NULL  # the params field from YAML
+  if (out_format('markdown')) {
+    if (child_mode()) {
+      # in child mode, strip off the YAML metadata in Markdown if exists
+      if (grepl('^---\\s*$', text[1])) {
+        i = grep('^---\\s*$', text)
+        if (length(i) >= 2) text = text[-(1:i[2])]
+      }
+    } else {
+      params = knit_params(text)
+      params = if (length(params))
+        c('params <-', capture.output(dput(params, '')), '')
+      .knitEnv$tangle.params = params  # for hook_purl()
+    }
   }
   # change output hooks only if they are not set beforehand
   if (identical(knit_hooks$get(names(.default.hooks)), .default.hooks) && !child_mode()) {
@@ -236,6 +254,7 @@ knit = function(input, output = NULL, tangle = FALSE, text = NULL, quiet = FALSE
   if (in.file && !quiet) message(ifelse(progress, '\n\n', ''), 'processing file: ', input)
   res = process_file(text, output)
   res = paste(knit_hooks$get('document')(res), collapse = '\n')
+  if (tangle) res = c(params, res)
   if (!is.null(output))
     writeLines(if (encoding == '') res else native_encode(res, to = encoding),
                con = output, useBytes = encoding != '')
@@ -266,10 +285,13 @@ purl = function(..., documentation = 1L) {
 
 process_file = function(text, output) {
   groups = split_file(lines = text)
-  n = length(groups); res = character(n); olines = integer(n)
+  n = length(groups); res = character(n)
   tangle = opts_knit$get('tangle')
 
-  if (opts_knit$get('progress')) {
+  # when in R CMD check, turn off the progress bar (R-exts said the progress bar
+  # was not appropriate for non-interactive mode, and I don't want to argue)
+  progress = opts_knit$get('progress') && !is_R_CMD_check()
+  if (progress) {
     pb = txtProgressBar(0, n, char = '.', style = 3)
     on.exit(close(pb), add = TRUE)
   }
@@ -280,7 +302,7 @@ process_file = function(text, output) {
       knit_exit(NULL)
       break  # must have called knit_exit(), so exit early
     }
-    if (opts_knit$get('progress')) {
+    if (progress) {
       setTxtProgressBar(pb, i)
       if (!tangle) cat('\n')  # under tangle mode, only show one progress bar
       flush.console()
@@ -345,7 +367,7 @@ auto_format = function(ext) {
 #' \command{SweaveInput} command in Sweave.
 #' @param ... arguments passed to \code{\link{knit}}
 #' @param options a list of chunk options to be used as global options inside
-#'   the child document (ignored if not a list); when we use the \code{child}
+#'   the child document (ignored if not a list); when one uses the \code{child}
 #'   option in a parent chunk, the chunk options of the parent chunk will be
 #'   passed to the \code{options} argument here
 #' @inheritParams knit
@@ -357,9 +379,10 @@ auto_format = function(ext) {
 #'   \code{\link{knit}()}; instead it must be placed in a parent document to let
 #'   \code{\link{knit}()} call it indirectly.
 #'
-#'   The path of the child document is relative to the parent document.
+#'   The path of the child document is determined relative to the parent document.
 #' @export
-#' @examples # you can write \Sexpr{knit_child('child-doc.Rnw')} in an Rnw file 'main.Rnw' to input results from child-doc.Rnw in main.tex
+#' @examples # you can write \Sexpr{knit_child('child-doc.Rnw')} in an Rnw file 'main.Rnw'
+#' # to input results from child-doc.Rnw in main.tex
 #'
 #' # comment out the child doc by \Sexpr{knit_child('child-doc.Rnw', eval = FALSE)}
 knit_child = function(..., options = NULL, envir = knit_global()) {
@@ -433,8 +456,8 @@ wrap.character = function(x, options) {
   knit_hooks$get('output')(x, options)
 }
 
-# if you provide a custom print function that returns a character object of
-# class 'knit_asis', I'll just write it as is
+# If you provide a custom print function that returns a character object of
+# class 'knit_asis', it will be written as is.
 #' @export
 wrap.knit_asis = function(x, options, inline = FALSE) {
   if (isFALSE(attr(x, 'knit_cacheable', exact = TRUE)) &&
@@ -461,11 +484,11 @@ wrap.source = function(x, options) {
 }
 
 msg_wrap = function(message, type, options) {
-  # when output format is latex, do not wrap messages (let latex deal with wrapping)
+  # when the output format is LaTeX, do not wrap messages (let LaTeX deal with wrapping)
   if (!length(grep('\n', message)) && !out_format(c('latex', 'listings', 'sweave')))
-    message = str_wrap(message, width = getOption('width'))
+    message = stringr::str_wrap(message, width = getOption('width'))
   knit_log$set(setNames(
-    list(c(knit_log$get(type), str_c('Chunk ', options$label, ':\n  ', message))),
+    list(c(knit_log$get(type), paste0('Chunk ', options$label, ':\n  ', message))),
     type
   ))
   knit_hooks$get(type)(comment_out(message, options$comment), options)
@@ -496,8 +519,11 @@ wrap.recordedplot = function(x, options) {
   fig.cur = plot_counter()
   options$fig.cur = fig.cur # put fig num in options
   name = fig_path('', options, number = fig.cur)
-  if (!file_test('-d', dirname(name)))
-    dir.create(dirname(name), recursive = TRUE) # automatically creates dir for plots
+  in_base_dir(
+    # automatically creates dir for plots
+    if (!file_test('-d', dirname(name)))
+      dir.create(dirname(name), recursive = TRUE)
+  )
   # vectorize over dev, ext and dpi: save multiple versions of the plot
   file = mapply(
     save_plot, width = options$fig.width, height = options$fig.height,
@@ -518,13 +544,13 @@ wrap.recordedplot = function(x, options) {
 #'
 #' Users can write custom methods based on this generic function. For example,
 #' if we want to print all data frames as tables in the output, we can define a
-#' method \code{knit_print.data.frame} that turns a data frame into a table (the
+#' method \code{knit_print.data.frame} that turns a data.frame into a table (the
 #' implementation may use other R packages or functions, e.g. \pkg{xtable} or
 #' \code{\link{kable}()}).
 #' @param x an R object to be printed
 #' @param ... additional arguments passed to the S3 method (currently ignored,
 #'   except two optional arguments \code{options} and \code{inline}; see
-#'   References)
+#'   the references below)
 #' @return The value returned from the print method should be a character vector
 #'   or can be converted to a character value. You can wrap the value in
 #'   \code{\link{asis_output}()} so that \pkg{knitr} writes the character value
@@ -610,7 +636,7 @@ knit_meta = function(class = NULL, clean = TRUE) {
     seq_along(.knitEnv$meta)
   } else if (length(.knitEnv$meta)) {
     # if a class was specified, match the items belonging to the class
-    which(sapply(.knitEnv$meta, inherits, what = class))
+    which(vapply(.knitEnv$meta, inherits, logical(1), what = class))
   }
   if (length(matches) < 1) return(list())
   if (clean) on.exit(.knitEnv$meta[matches] <- NULL, add = TRUE)
