@@ -4,7 +4,7 @@ kable2 = function(...) as.character(kable(...))
 
 assert(
   'kable() works on data frames/matrices of one row',
-  kable(data.frame(x=1, y=1), format = 'markdown') == c('|  x|  y|', '|--:|--:|', '|  1|  1|')
+  kable(data.frame(x = 1, y = 1), format = 'markdown') == c('|  x|  y|', '|--:|--:|', '|  1|  1|')
 )
 
 m = matrix(1:2, nrow = 1, dimnames = list('a', c('x', 'y')))
@@ -25,7 +25,7 @@ assert(
 
 assert(
   "kable() works on NA's",
-  identical(kable2(data.frame(x=c(NA, FALSE))), c('|x     |', '|:-----|', '|NA    |', '|FALSE |'))
+  identical(kable2(data.frame(x = c(NA, FALSE))), c('|x     |', '|:-----|', '|NA    |', '|FALSE |'))
 )
 
 assert(
@@ -48,7 +48,7 @@ x & y\\\\
 assert(
   'kable() escapes LaTeX special characters by default',
   identical(
-    kable2(data.frame(x=c("10%","5%"),col_name=c("3_8","40_6")), 'latex'),
+    kable2(data.frame(x = c("10%", "5%"), col_name = c("3_8", "40_6")), 'latex'),
     '
 \\begin{tabular}{l|l}
 \\hline
@@ -65,7 +65,7 @@ x & col\\_name\\\\
 assert(
   'kable() doesn\'t escape LaTeX special characters when escape = FALSE',
   identical(
-    kable2(data.frame(x=c("10%","5%"),col_name=c("3_8","40_6")), 'latex', escape = FALSE),
+    kable2(data.frame(x = c("10%", "5%"), col_name = c("3_8", "40_6")), 'latex', escape = FALSE),
     '
 \\begin{tabular}{l|l}
 \\hline
@@ -82,7 +82,7 @@ x & col_name\\\\
 assert(
   'kable() escapes HTML special characters by default',
   identical(
-    kable2(data.frame(x=c("10<>","5&2"),"y"=c("3>8","\"40\"")), 'html'),
+    kable2(data.frame(x = c("10<>", "5&2"), "y" = c("3>8", "\"40\"")), 'html'),
     "<table>\n <thead>\n  <tr>\n   <th style=\"text-align:left;\"> x </th>\n   <th style=\"text-align:left;\"> y </th>\n  </tr>\n </thead>\n<tbody>\n  <tr>\n   <td style=\"text-align:left;\"> 10&lt;&gt; </td>\n   <td style=\"text-align:left;\"> 3&gt;8 </td>\n  </tr>\n  <tr>\n   <td style=\"text-align:left;\"> 5&amp;2 </td>\n   <td style=\"text-align:left;\"> &quot;40&quot; </td>\n  </tr>\n</tbody>\n</table>"
   )
 )
@@ -90,7 +90,7 @@ assert(
 assert(
   'kable() doesn\'t escape HTML special characters when escape = FALSE',
   identical(
-    kable2(data.frame(x=c("10<>","5&2"),"y"=c("3>8","\"40\"")), 'html', escape = FALSE),
+    kable2(data.frame(x = c("10<>", "5&2"), "y" = c("3>8", "\"40\"")), 'html', escape = FALSE),
     "<table>\n <thead>\n  <tr>\n   <th style=\"text-align:left;\"> x </th>\n   <th style=\"text-align:left;\"> y </th>\n  </tr>\n </thead>\n<tbody>\n  <tr>\n   <td style=\"text-align:left;\"> 10<> </td>\n   <td style=\"text-align:left;\"> 3>8 </td>\n  </tr>\n  <tr>\n   <td style=\"text-align:left;\"> 5&2 </td>\n   <td style=\"text-align:left;\"> \"40\" </td>\n  </tr>\n</tbody>\n</table>"
   )
 )
@@ -136,3 +136,11 @@ assert(
   'kable(, "markdown") works for a 0 zero 1 column matrix',
   identical(kable2(x2, 'markdown'), c('|a  |', '|:--|'))
 )
+
+assert(
+  'kable() works on an irregular matrix',
+  identical(
+    kable2(matrix(list('a', 2, 3, 4), nrow = 2), col.names = c('a', 'b')),
+    c('|a  |b  |', '|:--|:--|', '|a  |3  |', '|2  |4  |')
+  )
+)
